Struct ExtImageCopyCaptureFrameV1
pub struct ExtImageCopyCaptureFrameV1 { /* private fields */ }wayland and Linux only.Expand description
image capture frame
This object represents an image capture frame.
The client should attach a buffer, damage the buffer, and then send a capture request.
If the capture is successful, the compositor must send the frame metadata (transform, damage, presentation_time in any order) followed by the ready event.
If the capture fails, the compositor must send the failed event.
See also the Request enum for this interface.
Implementations
impl ExtImageCopyCaptureFrameV1
impl ExtImageCopyCaptureFrameV1
pub fn transform(&self, transform: Transform)
pub fn transform(&self, transform: Transform)
buffer transform
This event is sent before the ready event and holds the transform that the compositor has applied to the buffer contents.
pub fn damage(&self, x: i32, y: i32, width: i32, height: i32)
pub fn damage(&self, x: i32, y: i32, width: i32, height: i32)
buffer damaged region
This event is sent before the ready event. It may be generated multiple times to describe a region.
The first captured frame in a session will always carry full damage. Subsequent frames’ damaged regions describe which parts of the buffer have changed since the last ready event.
These coordinates originate in the upper left corner of the buffer.
pub fn presentation_time(&self, tv_sec_hi: u32, tv_sec_lo: u32, tv_nsec: u32)
pub fn presentation_time(&self, tv_sec_hi: u32, tv_sec_lo: u32, tv_nsec: u32)
presentation time of the frame
This event indicates the time at which the frame is presented to the output in system monotonic time. This event is sent before the ready event.
The timestamp is expressed as tv_sec_hi, tv_sec_lo, tv_nsec triples, each component being an unsigned 32-bit value. Whole seconds are in tv_sec which is a 64-bit value combined from tv_sec_hi and tv_sec_lo, and the additional fractional part in tv_nsec as nanoseconds. Hence, for valid timestamps tv_nsec must be in [0, 999999999].
pub fn ready(&self)
pub fn ready(&self)
frame is available for reading
Called as soon as the frame is copied, indicating it is available for reading.
The buffer may be re-used by the client after this event.
After receiving this event, the client must destroy the object.
pub fn failed(&self, reason: FailureReason)
pub fn failed(&self, reason: FailureReason)
capture failed
This event indicates that the attempted frame copy has failed.
After receiving this event, the client must destroy the object.